searchData={"items":[{"type":"module","title":"PersistConfig","doc":"Persists the configurations from a list of files during compilation.\nAlso puts the current application name in a module attribute and provides\nmacros `get_env/2`, `get_app_env/3` and `get_all_env/1` for concise\nconfiguration value retrieval.","ref":"PersistConfig.html"},{"type":"module","title":"Installation - PersistConfig","doc":"Add `persist_config` to your list of dependencies in `mix.exs`. Also include\nthe required configuration files in the `package` definition of `mix.exs`:\n\n```elixir\ndef project do\n  [\n    app: :your_app,\n    ...\n    deps: deps(),\n    package: package(),\n    ...\n  ]\nend\n...\ndef deps do\n  [\n    {:persist_config, \"~> 0.4\", runtime: false}\n  ]\nend\n...\ndefp package do\n  [\n    files: [\"lib\", \"mix.exs\", \"README*\", \"config/persist*.exs\"],\n    maintainers: [...],\n    licenses: [...],\n    links: %{...}\n  ]\nend\n```","ref":"PersistConfig.html#module-installation"},{"type":"module","title":"Usage - PersistConfig","doc":"`use PersistConfig` supports the following options:\n\n- `:app`   - module attribute to hold the current application name,\n  defaults to `:app`\n- `:files` - wildcard paths, defaults to `[\"config/persist*.exs\"]`\n\nOption `:files` selects the files whose configurations will be persisted.\nEach wildcard path is relative to the root. If no matching files are found,\nno configurations will be persisted.\n\nThough not required, you can still import the configurations from the above\nmatching files in `config/config.exs` or friends. For example:\n\n```elixir\nimport Config\n\nimport_config \"persist_this_config.exs\"\n```\n\nEven when your project is used as a dependency, this package will load and\npersist the configurations from the specified files during compilation.\n\nFor example, you may configure some path to read an external file and want\nto still read that __very__ file when your app is a dependency (without and\ndespite any path configuration in the parent app). To achieve this, you may:\n\n__1.__ Use a module attribute as a __constant__:\n\n```elixir\nuse PersistConfig\n...\n@path get_env(:path)\n```\n\n__2.__ Create a configuration file named, say, `config/persist_path.exs`:\n\n```elixir\nimport Config\n\nconfig :words_cache, path: \"#{File.cwd!()}/assets/words.txt\"\n```\n\n__3.__ In `mix.exs`, specify a package definition like this:\n\n```elixir\ndef project do\n  [\n    app: :words_cache,\n    ...\n    deps: deps(),\n    package: package(),\n    ...\n  ]\nend\n...\ndef deps do\n  [\n    {:persist_config, \"~> 0.4\", runtime: false}\n  ]\nend\n...\ndefp package do\n  [\n    files: [... \"assets/words.txt\", \"config/persist*.exs\"],\n    maintainers: [...],\n    licenses: [...],\n    links: %{...}\n  ]\nend\n```\n\n#### Example 1\n\nThe current application name is in `@app` by default:\n\n```elixir\nuse PersistConfig, files: [\"config/persist_path.exs\"]\n...\n@all_env get_all_env(@app)\n@path get_env(:path)\n```\n\n#### Example 2\n\nThe current application name is in `@my_app` as an option:\n\n```elixir\nuse PersistConfig, app: :my_app\n...\n@my_attr get_app_env(@my_app, :my_attr)\n```\n\n#### Example 3\n\nYou can use macro `get_env/2` to retrieve configuration values at runtime\nwhen configuration is done by `config/config.exs` and friends:\n\n```elixir\nuse PersistConfig\n...\ndefp level, do: get_env(:level, :all)\n```","ref":"PersistConfig.html#module-usage"},{"type":"macro","title":"PersistConfig.__using__/1","doc":"Persists the configurations from a list of files during compilation.\nAlso puts the current application name in a module attribute.\n\n`use PersistConfig` supports the following options:\n\n- `:app`   - module attribute to hold the current application name,\n  defaults to `:app`\n- `:files` - wildcard paths, defaults to `[\"config/persist*.exs\"]`\n\nOption `:files` selects the files whose configurations will be persisted.\nEach wildcard path is relative to the root. If no matching files are found,\nno configurations will be persisted.","ref":"PersistConfig.html#__using__/1"},{"type":"macro","title":"PersistConfig.get_all_env/1","doc":"Returns all key-value pairs for `app`.","ref":"PersistConfig.html#get_all_env/1"},{"type":"macro","title":"PersistConfig.get_app_env/3","doc":"Returns the value for `key` in the given `app`'s environment.\n\nIf the configuration parameter does not exist, returns the `default` value.","ref":"PersistConfig.html#get_app_env/3"},{"type":"macro","title":"PersistConfig.get_env/2","doc":"Returns the value for `key` in the current application's environment.\n\nIf the configuration parameter does not exist, returns the `default` value.","ref":"PersistConfig.html#get_env/2"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}